import Popup from "@/components/popup/popup/index";
import style from "./index.module.less";
import { View, Image, ITouchEvent, ScrollView } from "@tarojs/components";
import WemetaTabs from "@/components/wemeta-tabs/index";
import Icon24Vip from "@/images/icon-24-vip.png";
import { useEffect, useState } from "react";
import Taro from "@tarojs/taro";
import { uploadImage } from "@/utils/http";
import { TEntityAsset, type TMediaType } from "@/types/index";
import { EUploadFileScene } from "@/consts/enum";
import { deleteAsset, listAssets } from "@/service/asset";
import { EAssetScene } from "@/consts/enum";
import { useCharacterStore, useCurrentCharacter } from "@/store/characterStore";
const themeColors = [
  '#FF7E80',
  '#FFB350',
  '#FFE945',
  '#CBF706',
  '#9DFF4D',
  '#06F7A3',

  '#FFB7B7',
  '#FFC67C',
  '#FFE7A0',
  '#FDFF7C',
  '#B7FF7C',
  '#A0FFE9',

  '#7CD8FF',
  '#63A9FF',
  '#8577FF',
  '#CE7EFF',
  '#FF7EF0',
  '#DADADA',

  '#A0F7FF',
  '#84B7FF',
  '#95AED1',
  '#BAB4FF',
  '#FFC2FE',
  '#FFA7D9',
];

import useSWR from "swr";

export interface IProps {
  show: boolean;
  setShow: (show: boolean) => void;
}
export default function Index({ show, setShow }: IProps) {
  const { saveCharacter } = useCharacterStore();
  const character = useCurrentCharacter();
  const [currentColor, setCurrentColor] = useState(
    character?.bgColor || "#CBF706"
  );
  const [currentBgImage, setCurrentBgImage] = useState(character?.bgImg || "");
  const [mediaValue, setMediaValue] = useState<TEntityAsset[]>([]);
  let loading  = false;
  const [page, setPage]  = useState(1)
  const pageSize = 10
  const fetcher = async ([url, page, pageSize]) => {
    const res = await listAssets({ page, pageSize, scene: EAssetScene.BG_IMAGE })
    if (res.code === 0 && res.data) {
      return res.data
    }
    throw new Error('Failed to fetch data')
  }
  // 使用 useSWR
  const { data } = useSWR(
    // key 数组，当这些值变化时会重新请求
    ['/v1/asset', page, pageSize],
    fetcher
  )

  // 加载更多数据
  const loadMore = () => {
    // 没数据就不加载更多
    if(data?.length){
      setPage(prev => prev + 1)
    }
  }

  const getBgMediaList = async () => {
    const res = await listAssets({
      page: 1,
      pageSize: 20,
      scene: EAssetScene.BG_IMAGE,
    });
    if (res?.data?.length) {
      setMediaValue(res.data);
    }
  };

  const setBgColor = async (color: string) => {
    if (!character) return;

    const res = await saveCharacter({
      profileId: character.profileId,
      bgColor: color,
    });
    if (res?.code === 0) {
      setCurrentColor(color);
    }
  };
  const setBgImage = async (imageLink: string) => {
    if (!character) return;

    const res = await saveCharacter({
      profileId: character.profileId,
      bgImg: imageLink,
    });
    if (res?.code === 0) {
      setCurrentBgImage(imageLink);
    }
  };

  const handleDeleteClick = async (e: ITouchEvent, item: TEntityAsset ) => {
    e.stopPropagation();

    Taro.showModal({
      title: "提示",
      content: "确定删除该组件吗？",
      async success(res) {
        if (res.confirm) {
          if (!item.id) {
            return;
          }
          const res = await deleteAsset(item.id);
          if (res.code === 0) {
            getBgMediaList();
          }
        } else if (res.cancel) {
          console.log("用户点击取消");
        }
      },
    });
  };

  const handleScrollToLower = ()=> {
    console.log('lower')
    loadMore();
  }

  let isUploading = false;
  const handleUploadClick = () => {
    Taro.chooseMedia({
      count: 1,
      mediaType: ["image", "video"],
      sourceType: ["album", "camera"],
      async success(res) {
        isUploading = true;
        const tmpPath = res.tempFiles[0].tempFilePath;
        Taro.showLoading();
        const response = await uploadImage(tmpPath, EUploadFileScene.BG_IMAGE);
        Taro.hideLoading();
        if (response?.code === 0 && response.data) {
          getBgMediaList();
        } else {
          Taro.showModal({
            title: "上传异常",
            content: response?.msg ?? "图片上传失败",
            showCancel: false,
          });
        }
        isUploading = false;
      },
      complete() {
        isUploading = false;
      },
      fail(err) {
        console.log(err);
      },
    });
  };
   
  const handleSetBlank = async () => {
    if(loading){
      return
    }
    loading = true;
    Taro.showLoading();
    const res = await saveCharacter({
      profileId: character?.profileId,
      bgImg: '',
    });
    Taro.hideLoading();
    loading = false
    if (res?.code === 0) {
      setCurrentBgImage('');
    }
  }

  const tabList = [
    {
      key: "1",
      label: "按钮颜色",
      children: (
        <View className={style.tabContent}>
          <View className={`grid grid-cols-6 gap-x-12 gap-y-24 box-border`}>
            {themeColors.map((item, index) => {
              return (
                <View
                  className={`rounded-full ${
                    currentColor === item
                      ? style.colorItemActived
                      : style.colorItem
                  }`}
                  style={{ backgroundColor: item }}
                  key={index}
                  onClick={() => {
                    setBgColor(item);
                  }}
                ></View>
              );
            })}
          </View>
        </View>
      ),
    },
    {
      key: "2",
      label: (
        <View className="flex items-center gap-4">
          自定义背景<Image src={Icon24Vip} className="w-12 h-12"></Image>
        </View>
      ),
      children: (
        <View className={`pb-68 ${style.tabContent}`}>
          <ScrollView scroll-y enable-flex style="flex-direction: row; height: 280px;" onScrollToLower={handleScrollToLower}>
            <View className="grid grid-cols-3 gap-x-8 gap-y-12">
              <View
                className={`flex items-center justify-center ${style.bgItemAddButton}`}
                onClick={handleUploadClick}
              >
                <Image
                  src="https://cdn.wehome.cn/cmn/png/100/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-VDZCWI2M-O91.png"
                  className="w-20 h-20"
                ></Image>
              </View>
              <View
                className={`flex items-center justify-center ${style.bgItemBlank}`}
                onClick={handleSetBlank}
              >
                
              </View>
              {mediaValue.map((item, index) => {
                return (
                  <View
                    className={`${
                      currentBgImage === item.link
                        ? style.bgItemActived
                        : style.bgItem
                    }`}
                    key={index}
                    onClick={() => {
                      item.link && setBgImage(item.link);
                    }}
                  >
                    {!item.isSystem && (
                      <View
                        onClick={(e) => handleDeleteClick(e, item)}
                        className="iconfont icon-icon_24_delet icon-24 text-white absolute right-8 top-10"
                      ></View>
                    )}
                    {item.link && (
                      <Image
                        src={item.link}
                        mode="widthFix"
                        className="w-full"
                      ></Image>
                    )}
                  </View>
                );
              })}
            </View>
          </ScrollView>
        </View>
      ),
    },
  ];

  useEffect(() => {
    if(data?.length){
      setMediaValue((prevdata)=> {
        return [...prevdata, ...data]
      })
    }
  }, [data]);

  return (
    <Popup title="背景设定" show={show} setShow={setShow}>
      <View style={{ height: "380px" }}>
        <WemetaTabs list={tabList} current="1" tabStyle="button"></WemetaTabs>
      </View>
    </Popup>
  );
}
