import { bluebookAiAgent } from "@/xiaolanbenlib/api/index";
import Taro from "@tarojs/taro";
import { getHeaders } from "@/xiaolanbenlib/module/axios.js";
import JsonChunkParser from "@/utils/jsonChunkParser";
import request from "@/xiaolanbenlib/module/axios.js";
import type { TMessage } from "@/types/bot";

export type TMessageHistories = {
  data: TMessage[][];
  nextId: string;
  totalCount: 0;
};

// 获取与指定智能体的历史会话记录--按智能体维度倒序返回
type TGetMessageHistoriesParams = {
  agentId: string;
  beginId?: string; // 起始ID, 如果未传入则获取最新的N条
  pageSize: number;
};
export const getMessageHistories = (data: TGetMessageHistoriesParams) => {
  return request.get<TMessageHistories>(
    `${bluebookAiAgent}api/v1/chat/messages`,
    { params: data }
  );
};

// 保存消息--追加覆盖保存模式

export type TAppendMessages = {
  "agentId": string,
  "loginId": string,
  "messages": {
    "content": string,
    "isStreaming": false,
    "msgUk": string,
    "role": string
  }[ ],
  "sessionId": string
}
export const appendMessages = (data: TAppendMessages) => {
  return request.post(`${bluebookAiAgent}api/v1/chat/messages/append`, data)
}


// 消息差评或取消差评
type TDislikeMessage = {
  "agentId": string,
  "dislikeReason": string,
  "isDislike": boolean,
  "msgUk": string
}
export const dislikeMessage = (data: TDislikeMessage) => {
  return request.put(`${bluebookAiAgent}api/v1/chat/messages/dislike`, data)
}

// 消息点赞或取消点赞
type TLikeMessage = {
  "agentId": string,
  "dislikeReason": string,
  "isDislike": boolean,
  "msgUk": string
}
export const likeMessage = (data: TLikeMessage) => {
  return request.put(`${bluebookAiAgent}api/v1/chat/messages/like`, data)
}





// 文本聊天，流式返回消息

export type TTextChatParams = {
  agentId: string;
  params: {
    message?: string;
    model?: string;
  };
  onStart: () => void;
  onReceived: (m: { content: string; reasoningContent: string }) => void;
  onFinished: () => void;
  onError: () => void;
};

export const textChat = ({
  agentId,
  params,
  onStart,
  onReceived,
  onFinished,
  onError,
}: TTextChatParams) => {
  onStart();

  let reqTask: Taro.RequestTask<any>;
  const jsonParser = new JsonChunkParser();
  jsonParser.onParseComplete((m) => {
    console.log("okok", m);
    onFinished();
  });
  const onChunkReceived = (chunk: any) => {
    // console.log(chunk);
    const uint8Array = new Uint8Array(chunk.data);
    var string = new TextDecoder("utf-8").decode(uint8Array);
    // console.log(string);
    jsonParser.parseChunk(string, (m) => {
      // console.log(m);
      onReceived(m);
    });
  };
  try {
    const url = `${bluebookAiAgent}api/v1/chat/completions`;
    reqTask = Taro.request({
      url: url,
      data: params,
      enableChunked: true,
      method: "POST",
      header: {
        ...getHeaders({
          url,
          params,
          method: "post",
        }),
      },
      responseType: "arraybuffer",
      success: function (res) {
        console.log("服务端响应 >>", res);
        // 如果没有识别或发生错误，则停止播放(恢复默认状态)
        if (res.header["Content-Type"]?.indexOf("application/json") > -1) {
        }
      },
    });

    // reqTask.
    reqTask.onChunkReceived(onChunkReceived);
  } catch (e) {
    onError();
  }

  const stopChunk = () => {
    reqTask.offChunkReceived(onChunkReceived);
  };

  return stopChunk;
};
