import { bluebookAiAgent } from "@/xiaolanbenlib/api/index";
import Taro from "@tarojs/taro";
import { getHeaders } from "@/xiaolanbenlib/module/axios.js";
import JsonChunkParser from "@/utils/jsonChunkParser";
import request from "@/xiaolanbenlib/module/axios.js";
import type { TKnowledgeListItem, TQAListItem } from "@/types/knowledge";



//我的知识库--列表
export type TKnowledgeListResponse = {
  "data": TKnowledgeListItem[][],
  "nextId": string,
  "totalCount": number
}
export const getKnowledgeList = ({startId, pageSize = 1}: {
  startId?: string;
  pageSize: number;
}) => {
  return request.get<TKnowledgeListResponse>(
    `${bluebookAiAgent}api/v1/my/knowledge/list`,
    { params: {startId, pageSize} }
  );
};

// 共享我的知识库至企业
export const shareToEnt = (data: 
  {
    "knowledgeIds": number[],
    "toEntId": string
  }
) => {
  return request.post(`${bluebookAiAgent}api/v1/my/knowledge/shareToEnt`, data)
}


// 我的知识库--信息流
export type TKnowledgeDataItem = {
  // 信息流内容 可能为null; 如：已成功解析2份知识 ,
  "content"?: string,
  // 信息流关联文件列表; 可能为 null ,
  "knowledgeList"?: TKnowledgeListItem[],
  "role": string,
  "streamId": number,
  "type": string
}
export type TKnowLedgeStreamResponse = {
  "data": TKnowledgeDataItem[][],
  "nextId": string,
  "totalCount": number
}
export const getMyKnowledgeStream = (data: {startId?: string, pageSize:number} ) => {
  return request.get<TKnowLedgeStreamResponse>(`${bluebookAiAgent}api/v1/my/knowledge/stream`, {params: data})
}


// 获取指定知识库项的详情信息
export type TKnowledgeDetailResponse = {
  "content": "string",
  "knowledgeList": TKnowledgeListItem[],
  "qaList": TQAListItem[],
  "role": "string",
  "streamId": number,
  "type": "string"
}

export const getMyKnowledgeDetail = (knowledgeId: string) => {
  return request.get<TKnowledgeDetailResponse>(`${bluebookAiAgent}api/v1/my/knowledge/${knowledgeId}`)
}

// 删除知识库 信息流记录；流删除会同步删除相关的记录项
export const deleteKnowledgeStream = (streamId: string) => {
  return request.delete(`${bluebookAiAgent}api/v1/my/knowledge/stream/${streamId}`,)
}

// 删除知识库 记录项
export const deleteKnowledge = (knowledgeId: string) => {
  return request.delete(`${bluebookAiAgent}api/v1/my/knowledge/${knowledgeId}`,)
}
// 删除指定知识库的 QA 项
export const deleteKnowledgeQa = (knowledgeId: string, qaId: string) => {
  return request.delete(`${bluebookAiAgent}api/v1/my/knowledge/${knowledgeId}/${qaId}`,)
}

// 更新指定的知识库 QA 项
export const updateKnowledgeQa = (knowledgeId: string, qaId: string, qa: TQAListItem) => {
  return request.put(`${bluebookAiAgent}api/v1/my/knowledge/${knowledgeId}/${qaId}`, qa)
}



// 企业知识库--列表
export const getEntKnowledgeList = (data: {
  entId: string;
  startId?: string;
  pageSize: number;
}) => {
  return request.get<TKnowledgeListResponse>(
    `${bluebookAiAgent}api/v1/ent/knowledge/list`,
    { params: data }
  );
};
// 获取指定知识库项的详情信息
export const getEntKnowledgeDetail = (knowledgeId: string) => {
  return request.get<TKnowledgeDetailResponse>(`${bluebookAiAgent}api/v1/ent/knowledge/${knowledgeId}`)
}

// 企业知识库--信息流
export const getEntKnowledgeStream = (data: {entId: string, startId?: string, pageSize:number} ) => {
  return request.get<TKnowLedgeStreamResponse>(`${bluebookAiAgent}api/v1/ent/knowledge/stream`, {params: data})
}



