// 我的音色库&形象库
import {
  bluebookAiAgent,
} from '@/xiaolanbenlib/api/index'
import request from '@/xiaolanbenlib/module/axios.js'
import Taro from '@tarojs/taro'

import {FileTypes} from '@/consts'

export type TAvatarItem = {
  "avatarId": number,
  "avatarUrl": string,
  "isOriginal": boolean
}
// 上传形象--并生成微视频
export type TUploadAvatarResponse = {
  "avatars": TAvatarItem[],
  "failedReason": string,
  "status": string,
  "taskId": string
}
export const uploadAvatar = (data: {
  "aiGenerated": boolean,
  "avatarUrl": string,
  "description": string
}) => {
  return request.post<TUploadAvatarResponse>(`${bluebookAiAgent}api/v1/my/avatar`, data)
}

// 获取上传形象任务的处理状态
export const getUploadedAvatarStatus = (taskId: string) => {
  return request.get<TUploadAvatarResponse>(`${bluebookAiAgent}api/v1/my/avatar/task/${taskId}`)
}

// 获取个人形象库
export const getMyAvatars = (taskId: string) => {
  return request.get<TAvatarItem[]>(`${bluebookAiAgent}api/v1/my/avatar/task/${taskId}`)
}

// 删除指定的形象记录
export const deleteAvatar = (avatarId: string) => {
  return request.delete(`${bluebookAiAgent}api/v1/my/avatar/${avatarId}`)
}

// 用户上传文件--返回{'fileId':'xxxx', 'publicUrl':'xxxx'}
// /blue-aiagent/api/v1/my/upload

export const uploadFilesFromWechat = ()=> {
  Taro.chooseMessageFile({
    count: 10,
    type: "file",
    extension: FileTypes.map((f) => `${f}`),
    success(res) {
      const tempFilePaths = res.tempFiles;
      console.log("tempFilePaths", tempFilePaths);
      const files = tempFilePaths.map((file) => {
        return {
          file,
          status: 0,
          fileProgress: {
            progress: 0,
            totalBytesSent: 0,
            totalBytesExpectedToSend: 0,
          },
        };
      });
      // setUploadingList(files);
      // setUploadList(files);
      console.log(files);
    },
  });
}


// 前端获取自主上传文件至存贮的安全令牌
export type TUploadSecurityToken = {
  "accessKeyId": string,
  "accessKeySecret": string,
  "expiration": string,
  "fullPath": string,
  "publicUrl": string,
  "securityToken": string,
  "statusCode": string
}

export const getUploadSecurityToken = () => {
  return request.get<TUploadSecurityToken>(`${bluebookAiAgent}api/v1/my/upload/securityToken`)
}

// 克隆一个新的音色
export type TVoiceItem = {
  "createTime": string,
  "failedReason": string,
  "platform": string,
  "sourceUrl": string,
  "status": string,
  "voiceId": string,
  "voiceName": string
}
export const cloneVoice = (data: {
  "sourceUrl": string,
  "voiceText": string
}) => {
  return request.post<TVoiceItem>(`${bluebookAiAgent}api/v1/voice/clone`, data)
}

// 删除指定克隆的音色
export const deleteVoice = (voiceId: string)=> {
  return request.delete(`${bluebookAiAgent}api/v1/voice/clone/${voiceId}`)
}

// 获取指定克隆的音色记录--用于状态轮询
export const getVoice = (voiceId: string) => {
  return request.get<TVoiceItem>(`${bluebookAiAgent}api/v1/my/voice/${voiceId}`)
}

// 获取个人录音音色库
export const getVoices = () => {
  return request.get<TVoiceItem[]>(`${bluebookAiAgent}api/v1/my/voices/`)
}


